EnhancedPreferencesWeb class

A web implementation of the EnhancedPreferencesPlatform of the EnhancedPreferences plugin.

Inheritance

Constructors

EnhancedPreferencesWeb()
Constructs a EnhancedPreferencesWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBool(String key, [bool enableEncryption = false]) → Future<bool?>
override
getDouble(String key, [bool enableEncryption = false]) → Future<double?>
override
getInt(String key, [bool enableEncryption = false]) → Future<int?>
override
getString(String key, [bool enableEncryption = false]) → Future<String?>
override
keys() → Future<List<String>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<String?>
override
setBool(String key, bool value, [bool enableEncryption = false]) → Future<String?>
override
setDouble(String key, double value, [bool enableEncryption = false]) → Future<String?>
override
setInt(String key, int value, [bool enableEncryption = false]) → Future<String?>
override
setString(String key, String value, [bool enableEncryption = false]) → Future<String?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void